`sgqlc.operation` module
========================

.. automodule:: sgqlc.operation
    :members: Operation, Selection, Selector, SelectionList
    :special-members:
    :show-inheritance:
    :private-members:
